==> seedsui-react-5.8.44.tgz: package/lib/Modal/Picker/index.js <==
var _excluded = ["visible", "onVisibleChange", "portal", "animation", "maskProps", "captionProps", "submitProps", "cancelProps", "maskClosable", "children"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import { createPortal } from 'react-dom';
import Head from "./Head";

// Picker
var Picker = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    onVisibleChange = _ref.onVisibleChange,
    portal = _ref.portal,
    _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'slideUp' : _ref$animation,
    maskProps = _ref.maskProps,
    captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    _ref$maskClosable = _ref.maskClosable,
    maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 节点
  var modalRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: modalRef === null || modalRef === void 0 ? void 0 : modalRef.current,
      getRootDOM: function getRootDOM() {
        return modalRef.current;
      }
    };
  });
  useEffect(function () {
    if (visible === null) return;
    if (onVisibleChange) onVisibleChange(visible);

    // eslint-disable-next-line
  }, [visible]);

  // 事件
  function handleCancelClick(e) {
    if (cancelProps !== null && cancelProps !== void 0 && cancelProps.onClick) cancelProps.onClick(e);
    if (onVisibleChange) onVisibleChange(false);
  }
  function handleMaskClick(e) {
    e.stopPropagation();
    if (!e.target.classList.contains('mask')) return;
    if (maskProps !== null && maskProps !== void 0 && maskProps.onClick) maskProps.onClick(e);
    if (maskClosable && onVisibleChange) onVisibleChange(false);
  }
  var Node = /*#__PURE__*/React.createElement("div", _extends({}, maskProps, {
    className: "mask picker-mask".concat(maskProps !== null && maskProps !== void 0 && maskProps.className ? ' ' + maskProps.className : '').concat(visible ? ' active' : ''),
    onClick: handleMaskClick,
    ref: modalRef
  }), /*#__PURE__*/React.createElement("div", _extends({
    "data-animation": animation
  }, props, {
    className: "popup-animation picker".concat(props.className ? ' ' + props.className : '').concat(visible ? ' active' : '')
  }), /*#__PURE__*/React.createElement(Head, {
    captionProps: captionProps,
    cancelProps: cancelProps,
    submitProps: submitProps,
    onCancelClick: handleCancelClick
  }), children));
  if (portal === null || portal === false) {
    return Node;
  }
  return /*#__PURE__*/createPortal(Node, portal || document.getElementById('root') || document.body);
});
export default Picker;

==> seedsui-react-5.8.90.tgz: package/lib/Modal/Picker/index.js <==
var _excluded = ["visible", "onVisibleChange", "portal", "animation", "maskProps", "captionProps", "submitProps", "cancelProps", "maskClosable", "children"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import { createPortal } from 'react-dom';
import Head from "./Head";

// Picker
var Picker = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    onVisibleChange = _ref.onVisibleChange,
    portal = _ref.portal,
    _ref$animation = _ref.animation,
    animation = _ref$animation === void 0 ? 'slideUp' : _ref$animation,
    maskProps = _ref.maskProps,
    captionProps = _ref.captionProps,
    submitProps = _ref.submitProps,
    cancelProps = _ref.cancelProps,
    _ref$maskClosable = _ref.maskClosable,
    maskClosable = _ref$maskClosable === void 0 ? true : _ref$maskClosable,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 节点
  var modalRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: modalRef === null || modalRef === void 0 ? void 0 : modalRef.current,
      getRootDOM: function getRootDOM() {
        return modalRef.current;
      }
    };
  });
  useEffect(function () {
    if (visible) {
      if (onVisibleChange) onVisibleChange(visible);
    }
    // eslint-disable-next-line
  }, [visible]);

  // 事件
  function handleCancelClick(e) {
    if (cancelProps !== null && cancelProps !== void 0 && cancelProps.onClick) cancelProps.onClick(e);
    onVisibleChange && onVisibleChange(false);
  }
  function handleMaskClick(e) {
    e.stopPropagation();
    if (!e.target.classList.contains('mask')) return;
    if (maskProps !== null && maskProps !== void 0 && maskProps.onClick) maskProps.onClick(e);
    if (maskClosable) {
      onVisibleChange && onVisibleChange(false);
    }
  }
  var Node = /*#__PURE__*/React.createElement("div", _extends({}, maskProps, {
    className: "mask picker-mask".concat(maskProps !== null && maskProps !== void 0 && maskProps.className ? ' ' + maskProps.className : '').concat(visible ? ' active' : ''),
    onClick: handleMaskClick,
    ref: modalRef
  }), /*#__PURE__*/React.createElement("div", _extends({
    "data-animation": animation,
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, props, {
    className: "popup-animation picker".concat(props.className ? ' ' + props.className : '').concat(visible ? ' active' : '')
  }), /*#__PURE__*/React.createElement(Head, {
    captionProps: captionProps,
    cancelProps: cancelProps,
    submitProps: submitProps,
    onCancelClick: handleCancelClick
  }), children));
  if (portal === null || portal === false) {
    return Node;
  }
  return /*#__PURE__*/createPortal(Node, portal || document.getElementById('root') || document.body);
});
export default Picker;
